package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(@@`````````0```````
M`+%X``````!``#@`"0!``!<`%@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````&``````````8``````````$````!
M````!0```````````````````````````````````````*0@````````I"``
M```````0``````$````&````````J\````````"[P````````+O`````````
M!,`````````%&````````!```````@````8```````"KT````````+O0````
M````N]`````````!X`````````'@``````````@````$````!`````````)0
M`````````E`````````"4``````````D`````````"0`````````!&1TY5``
M```$````````G9@```````"=F````````)V8`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O`````````N\``````
M``"[P`````````1`````````!$```````````2]L:6(O;&0M;75S;"US,SDP
M>"YS;RXQ``````0````4`````T=.50#8O>]UR:+_5;(BC<W\=WC^-A+;!P``
M```````1````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D"`*&""`($
MND$8@(@`````````10```$D```!-````3@```%4```!6````5P````````!9
M````6@````````!;````7````%X``````````"U'WLX?W\5N?)I_:@[OT^NV
MF\4N#O&-N`[D_R!\U&35'%AQV6^+`;*;PT^8+#_EPH?7^D)@;*'Z?)+CN@'&
M1^/2/,-59LRO9]-P!XCLU45#[=MB,\PEC!6;G*E_"@*GX%">&FM)^^"C````
M```````````````````````````````````````#```(````````&$@`````
M`````````H`2`````````````````````````````902````````````````
M`````````````$L2`````````````````````````````F\2````````````
M`````````````````6@2`````````````````````````````#T2````````
M`````````````````````1D2`````````````````````````````=<2````
M`````````````````````````*H2`````````````````````````````+,B
M`````````````````````````````3$2````````````````````````````
M`;P2`````````````````````````````ET2````````````````````````
M`````7D2`````````````````````````````/P2````````````````````
M`````````G@2`````````````````````````````K\A````````````````
M`````````````#<2`````````````````````````````KX1````````````
M`````````````````:\1`````````````````````````````2`2````````
M`````````````````````D82`````````````````````````````%L2````
M`````````````````````````?82`````````````````````````````L`1
M`````````````````````````````)L2````````````````````````````
M`AT2`````````````````````````````!\@````````````````````````
M`````482`````````````````````````````-T@````````````````````
M`````````&,2`````````````````````````````),2````````````````
M`````````````/<2`````````````````````````````%,2````````````
M`````````````````$02`````````````````````````````!`2````````
M`````````````````````A02`````````````````````````````H<2````
M`````````````````````````8@2`````````````````````````````'(@
M`````````````````````````````J@2````````````````````````````
M`C82`````````````````````````````>,2````````````````````````
M``````$2`````````````````````````````^D2````````````````````
M`````````B@2`````````````````````````````J`2````````````````
M``````````````D1`````````````````````````````@02````````````
M`````````````````&02`````````````````````````````F02````````
M`````````````````````!@2`````````````````````````````0(2````
M`````````````````````````-@2`````````````````````````````546
M`````````````````````````````J\2````````````````````````````
M`HX2`````````````````````````````(X2````````````````````````
M`````*,2`````````````````````````````&D2````````````````````
M`````````3@2`````````````````````````````E$2````````````````
M`````````````1,2`````````````````````````````,(@````````````
M`````````````````<T2`````````````````````````````)H2````````
M`````````````````````=(2`````````````````````````````W$2```*
M````````.'@````````&.````WX2```*````````02@`````````T@```IL2
M```*````````'X@````````"@````:D2```+````````7/@``````````@``
M`O42```*````````*L``````````!@```_42```(````````&$@`````````
M`@```RH2```*````````*L@````````";````S\2```*````````/K``````
M```"=````XH0```4````````P(```````````````Q`2```*````````-&@`
M````````=@```S<2```*````````-.``````````=````U42```*````````
M*6``````````.````V82```*````````60@````````!E@```Y82```*````
M````-Y@`````````V@```\40```4````````P-@``````````````\H2```*
M````````+3@`````````-````UT2```*````````(C@`````````/````QX2
M```*````````+7`````````!8@```P81```3````````P'@`````````"```
M`[X0```3````````P(```````````````X\2```*````````(@@`````````
M`````_(2```*````````6)@`````````;````]<2```*````````-V@`````
M````+````Z@2```*````````*9@````````!)````_L2```*````````6J``
M```````"5````N@2```*````````+M@````````%C`!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T
M<G-T<@!V9G!R:6YT9@!S=')C:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`;65M
M8W!Y`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`<VYP<FEN=&8`<F5A9&1I<@!S=')C
M<'D`<W1R=&]K`%]?;&EB8U]S=&%R=%]M86EN`'-P<FEN=&8`<W1R9'5P`'!T
M:')E861?871F;W)K`%]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US
M,SDP>"YS;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`&UY7W!A
M<E]P;`!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P
M87)?9&EE`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C
M`'-H85]U<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?8G-S7W-T
M87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O8P!?
M961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB+W!E<FPU+V-O<F5?
M<&5R;"]#3U)%````````````````N\``````````#````````"-0````````
MN\@`````````#````````"+H````````OZ``````````#````````!A(````
M````O]``````````#````````!^(````````O^``````````#````````%SX
M````````P```````````#````````,``````````P!@`````````#```````
M`&`$````````P"``````````#````````%U@````````P#``````````#```
M`````%X`````````P#@`````````#````````%X$````````P$``````````
M#````````%_X````````P$@`````````#````````%UF````````P%``````
M````#````````&``````````P&``````````#````````%_H````````P&@`
M````````#````````%_N````````P'@`````````#````````&`*````````
MOX@````&````"@``````````````````OY`````+````"@``````````````
M````OY@````5````"@``````````````````OZ@````:````"@``````````
M````````O[`````=````"@``````````````````O[@````?````"@``````
M````````````O\`````I````"@``````````````````O\@````K````"@``
M````````````````O]@````L````"@``````````````````O^@````Q````
M"@``````````````````O_`````X````.```````````````````O_@```!!
M````"@``````````````````O<@````"````"P``````````````````O=``
M```#````"P``````````````````O=@````$````"P``````````````````
MO>`````%````"P``````````````````O>@````'````"P``````````````
M````O?`````(````"P``````````````````O?@````)````"P``````````
M````````O@`````*````"P``````````````````O@@````+````"P``````
M````````````OA`````,````"P``````````````````OA@````-````"P``
M````````````````OB`````.````"P``````````````````OB@````/````
M"P``````````````````OC`````0````"P``````````````````OC@````1
M````"P``````````````````OD`````3````"P``````````````````OD@`
M```6````"P``````````````````OE`````7````"P``````````````````
MOE@````8````"P``````````````````OF`````9````"P``````````````
M````OF@````;````"P``````````````````OG`````<````"P``````````
M````````OG@````=````"P``````````````````OH`````>````"P``````
M````````````OH@````@````"P``````````````````OI`````A````"P``
M````````````````OI@````B````"P``````````````````OJ`````C````
M"P``````````````````OJ@````D````"P``````````````````OK`````E
M````"P``````````````````OK@````F````"P``````````````````OL``
M```G````"P``````````````````OL@````H````"P``````````````````
MOM`````J````"P``````````````````OM@````M````"P``````````````
M````ON`````N````"P``````````````````ON@````O````"P``````````
M````````OO`````P````"P``````````````````OO@````R````"P``````
M````````````OP`````S````"P``````````````````OP@````T````"P``
M````````````````OQ`````U````"P``````````````````OQ@````V````
M"P``````````````````OR`````W````"P``````````````````OR@````Y
M````"P``````````````````OS`````Z````"P``````````````````OS@`
M```[````"P``````````````````OT`````\````"P``````````````````
MOT@````]````"P``````````````````OU`````^````"P``````````````
M````OU@````_````"P``````````````````OV````!`````"P``````````
M````````OV@```!!````"P``````````````````OW````!"````"P``````
M````````````OW@```!#````"P``````````````````OX````!$````"P``
M````````Z^_P<``DN00`#Z?[_V#C`/```"3K[_$0``0'_N,0\#@`),`0``!2
MH]('\#`0".,0$!``!`?Q!P`'``<`P!```%*BXQ`0```$!_$-$.,0$`P`%,#T
M____Y0````#`$```4I;C$!````0'\0T0XQ`0#``4P/3____5````&,`0``!2
MBN,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```%)^XQ`0```$!_$-$.,0
M$`P`%,#T____M0```$C`$```4G+C$!````0'\0T0XQ`0#``4P/3___^E````
M8,`0``!29N,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!```%):XQ`0```$
M!_$-$.,0$`P`%,#T____A0```)#`$```4D[C$!````0'\0T0XQ`0#``4P/3_
M__]U````J,`0``!20N,0$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```%(V
MXQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```4BKC$!````0'\0T0XQ`0
M#``4P/3___]%````\,`0``!2'N,0$```!`?Q#1#C$!`,`!3`]/___S4```$(
MP!```%(2XQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```4@;C$!````0'
M\0T0XQ`0#``4P/3___\5```!.,`0``!1^N,0$```!`?Q#1#C$!`,`!3`]/__
M_P4```%0P!```%'NXQ`0```$!_$-$.,0$`P`%,#T___^]0```6C`$```4>+C
M$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!1UN,0$```!`?Q#1#C$!`,
M`!3`]/___M4```&8P!```%'*XQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`
M$```4;[C$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!1LN,0$```!`?Q
M#1#C$!`,`!3`]/___J4```'@P!```%&FXQ`0```$!_$-$.,0$`P`%,#T___^
ME0```?C`$```49KC$!````0'\0T0XQ`0#``4P/3___Z%```"$,`0``!1CN,0
M$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```%&"XQ`0```$!_$-$.,0$`P`
M%,#T___^90```D#`$```47;C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0
M``!1:N,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```%%>XQ`0```$!_$-
M$.,0$`P`%,#T___^-0```HC`$```45+C$!````0'\0T0XQ`0#``4P/3___XE
M```"H,`0``!11N,0$```!`?Q#1#C$!`,`!3`]/___A4```*XP!```%$ZXQ`0
M```$!_$-$.,0$`P`%,#T___^!0```M#`$```42[C$!````0'\0T0XQ`0#``4
MP/3___WU```"Z,`0``!1(N,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!``
M`%$6XQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```40KC$!````0'\0T0
MXQ`0#``4P/3___W%```#,,`0``!0_N,0$```!`?Q#1#C$!`,`!3`]/___;4`
M``-(P!```%#RXQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`$```4.;C$!``
M``0'\0T0XQ`0#``4P/3___V5```#>,`0``!0VN,0$```!`?Q#1#C$!`,`!3`
M]/___84```.0P!```%#.XQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```
M4,+C$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!0MN,0$```!`?Q#1#C
M$!`,`!3`]/___54```/8P!```%"JXQ`0```$!_$-$.,0$`P`%,#T___]10``
M`_#`$```4)[C$!````0'\0T0XQ`0#``4P/3___TU```$",`0``!0DN,0$```
M!`?Q#1#C$!`,`!3`]/___24```0@P!```%"&XQ`0```$!_$-$.,0$`P`%,#T
M___]%0``!#C`$```4'KC$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!0
M;N,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```%!BXQ`0```$!_$-$.,0
M$`P`%,#T___\Y0``!(#`$```4%;C$!````0'\0T0XQ`0#``4P/3___S5```$
MF,`0``!02N,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!```%`^XQ`0```$
M!_$-$.,0$`P`%,#T___\M0``!,C`$```4#+C$!````0'\0T0XQ`0#``4P/3_
M__RE```$X,`0``!0)N,0$```!`?Q#1#C$!`,`!3`]/___)4```3XP!```%`:
MXQ`0```$!_$-$.,0$`P`%,#T___\A0``!1#`$```4`[C$!````0'\0T0XQ`0
M#``4P/3___QU```%*`````#K;_`P`"3C\/\X_W'C,/"H`"3C0/"@`"10(/"T
M04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`Y?___=#$2```4`?$
M*```3]RY!``TP.7___\5Q!@``$_<E0`0`*>$`+;`,```4`'C4#````18H/"T
M[)H`!`#8N10`Z>-EL```!.LN``,`#98#9(JGJ@`#P.7___]4XQ#PJ``$P#``
M`!_<XP`0```$XS`@"``DXP`@```DN00`4L0K``!0/L!````?S>-`4!@`),0H
M``!0$>,@4!``)%B0\+3LG`#%`7[LZ0`#`-CL"?__`-A!,!`(IR@`!*<!``&G
M=`""B````;D4`$+L$@`!`-CKY``#``VY%`!AXT`P```$XTY0```DZQ8``P`-
MXV`P"``$XV%0```DIRH``J<[`!"G!O_C[&D``P#8N10`EKD4`$KKJ0`#``U!
M*E``IVD``.5((````,`P```#_L0H``!/[\#E___\UNPH`%0`?L0H``!/YD%@
M\+S`Y?___?NY!``VN00`DL`@```>2\#E```!-^PH`$<`?,0H``!/T<#E___^
M^,#E___^M=4'\,"P**=T`%FY!``IZV_P^``$!_[`Y?___A?$*P``3[KL*`!.
M`'S`Y?___$[`,```3T'C(#````3C0K````22`$E^I_3_..,P,```!.,P4"``
M)*<H``5!,!`0["[_=F!VI_3_E,0H``!/E<#E___]3*?T_ZG`4```3XGC(%``
M``*GA``'P.4```^QI_3_L;D$`#;`(```'<?`Y0```-O$*P``3W3L*/^D`'RG
M]/_MIV@`!*?T_V[`Y?___$:G*0`!P.7___WQN00`+\`P````$N,P,```&*?[
M_V"G"0``XP#P```DP/0````)!P<'!P``F:`'!P<'ZV_P,``D04`@"./P_UC_
M<<1H``!.S.5(\*```,18``!.IN,P(`0`%,0H``!.N,#E___]W^MO\-@`!`?^
M!P<'!\`0``!/!,`@``!/`>P2``J`9,08``!.F^P8``0`?`?Q!_X'!P<'!P?`
M$```3O#`(```3NVY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`"NPX``T`?,08
M``!.=NP8``<`?,`@``!.U`?Q!_X'!P<'!P?KO_!8`"3`L```3LGC\/]@_W&5
M`+``IW0`(\`0``!.1^,0$````J>$``C$*```3G?`Y?__^S;`Y?___ZW`(```
M3D;C$"````*GA``(P"```#V>P.7___P%D@&P`.N_\/@`!`?^!P<'!\`0``!.
M5.,0$````J>$`!?K[_!P`"3`,```3I'C\/]@_W'`(```/7_`Y?___<;K[_$0
M``3`]/___X[`]/___XOK;_`P`"3C\/]@_W'L*`!<`'S$&```3@/C<!````*G
MA`!3N00`@KD$`&/C`"```)2Y!`"2E0`@`*>$`$[L"``,/7Y!D)`!XP"0``"4
ME0"0`*=T__8;F..@<````J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E___[
M\.PF``D`?D$IH`"5/2``IX0`#T&PL`CCH+````*G=/_IN00`*NMO\-``!`?^
M0:F@`;GI<#NY!``JZT,``P`*4$!@`.MO\-``!`?^IZD``+D$`"KK;_#0``0'
M_J>8``"G]/^_!P<'!^NO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/
M`+'2!_$PL"C`Y?__^W;L)@`A`'X8$J<X0`!8(/"XP"L``/``[",`"(!VI0^@
M`.P@`!-@=KD$`"JG.0`"P.7___QL$!*G&O__B!``'Z?T``2G&```U0?Q,+`H
MN10`(:=T``;KK_&(``0'_L#E___ZQ>N/\$``)./P_LC_<;)/`(#KB``@``VR
M3P"!T@?Q,(`H["@`"0!\N00`LI4`(`"G=``+U0?Q,(`HIW0`D>N/\7@`!`?^
MP.7___O`N00`DNPH__(`?+D$`"G`Y?__^G;L*`!A`'Q!H"`3E2X@$Z=T``:5
M`*`!IX3_\)4N(!.GA`!>IP@``+D$`#JY!``;ITD``+)>`$.G%/_^N0D`2J<I
M``"R7@`AIQ3__KD)`"L:)*<J``*Y%``BP.7___H7N00`6L`P```;K+D$`**Y
M!`!+P.7___NKN00`*D$P\*#`Y?__^\3L*``-_WY8`/"XIUA``,`+``#P`.P%
M`"N`=KD$`"K`Y?__^P*Y!``JP.7___RMN00`*<#E___Z&.PF_Z4`?+D$`"G`
MY?___#"Y!``KP.7___G[I_3_?Y4NH`&G=/^BE0"@`J>$_XBG]/^<N00`*L#E
M____6*?T_]C`Y?__^A7K;_`P`"3C\/](_W&R3P!@ZV8`(``-LD\`8;D$`++2
M!_"P8"BY!`"CE3TP`*=T``1!H#`!IP@``+D$`!JGB0``N00`*[)>`(&G%/_^
M03#PK+D)`(K`Y?___F[L*`"7`'RG"```I]D``+D$`.*R7@#>IQ3__KD)`-+L
MC0!VP&7C`/"L`!3$V```3&+K<``#``WC(+```)2Y!`!+E0"P`*=T``VG]`#F
M04!``>,@0```E)4`0`"GA``%[";_]SU^N0D`2[D4`)1!*)`"N00`A^.`T```
M",#E___Y6.,@@```).PH`#D`?.,PT```!.-0L```D./G,```!$)0X`!!<+`!
M&`7L5@`0`'RG]``\XQ!P``"00A"P`4%P<`$8`>P8`#(`?$(`\*"Y!`"^E3WP
MH$'@X`&G=/_MDCVP`*?9``#C3:```)!"3;`!I]L``>Q&__D`?-4'\+!@**=T
M`)7K;_#H``0'_J>9``#CB:```)!"B2``IYL``>R&__D`?*?T_^NY!`"^I_3_
MV<38``!+X.-PT```!.,0<````J>$`&ZY!`!'IY@``!@IIYH``4%`0`CC,$``
M``*G=/_XIRH``[D4``+K(``#``W`,```3$CC$#```!*G=``VP%```$Q`Y4Q0
M```!P.7___C0XR#PH``D["C_L0!\N10`Z;D$`#?K?@`#``VY!`!'P.7___@N
MXR#PH``$XR#0```D4)#PK.-0\*``!*>:``&Y%`"9ZSD``P`-01-0`.5($```
M`*?T_RJY!``RN00`)\#E___YON,@\*``).,@T```).PH_WP`?+D4`$GK=``#
M``VG]/_8IYD``*?T_RJG*0`0IY@``*?T_Z7`Y?__^-'K;_`P`"3`$```2X'C
M\/]8_W'CL!````3`4```.D#$2```2V'`,```&@FR3P"@ZZH`(``-LD\`H>,K
MH```!,!@```;7,#E___X_+D$`%;E2/"@``#`0```"KKC*Z````3`,```&?G`
MY?__^#OK;_#8``0'_@<'!P>R3P`@P!```$M&ZS(`(``-XT`0```$LD\`,<!0
M```Z`^,D,```!,1(``!+(<`P```9R<#T___XR>MO\#``)./P\`#_<>,`__@`
M(./P\`#_<>,`__@`(./P_U#_<>,`\*@`(.,0\*@"<;)/`)#KF0`@``VR3P"1
M0;#PIM('$`"0*,#E___WDL!@```9M;D$`%+`0```&;*Y!``KISD0`<#E___W
M<^PH`%7_?KD$``+C@/"G`7&Y!``KN00`..P`$``@<:=)$`#`Y?__]Y^Y!`!B
M["0`/P!^IRH``;D4`"+`Y?__]].Y!`"B["@`,P!\N10`MNPH``>@9;GHL#*Y
M84"#[*@`(2!EN00`.+D$`$NY!``J[+`0`2!QP.7___=605N@`)(`4`#CX/"H
M`G'5!^``D"BG=``2N00`*NMO\.`"!`?^N>BP2+EA0*2G]/_>IZD``*?T_^K`
MY?__]^<'!P<'P/3___]L!P?K;_`P`"3C\/``_W'C`/_X`"#C\/ZX_W'C`/%`
M`"#C$/%``7&Y!`"RN00`D[)/`'!!,/"LZW<`(``-P"```!DPLD\`<=('$`!P
M*,#E___\/Z<Y`"^Y!`"BN00`*\#E___YH.PH`!D`?,`@```9'KD$`#O`Y?__
M_9.Y!``KXX#Q0`%QU0>``'`HIW0`[^MO\7@!!`?^N00`*<#E___XHL`P```9
M"L#E___X?+D$`%+L*/_=`'Q!D/%`08#PL)4`4`"GA`"8[*@`#P!\IP@``+D$
M`#6Y!``JLET`,J<4__ZGA`!XIP@``*=)``"Y!`!ELEX`1J<4__ZYZ5`DXQ!/
M__]Q[%$`-Z!EN>E0`:<!``&GA``.E2\0`*=T`""2`!``XQ`?__]Q[%$`&8!D
MZ^```0`,E2\0`*=T`!&2`!``ZR\?__]5IW0`"NL`'___4N,0'_[_<:?G_^^G
M"```IRD``+D$`#6R7@`CIQ3__KD)`"6G"```ITD``+D$`&NGZ0__LEX`1J<4
M__ZY"0!+000@`>P._VT@9>.P\*``)+D$`"G`8```&(O`0```&0*G.1``P.7_
M__8WIU@0`*<J``'L)0`HP'>G]``!E0"@`:=T`!K`,```&'*G*0``P.7___?B
MN00`4NPH_T,`?)4`4`"G=/]L[*@`!P!\E2Z@`*>$_^:G*0`!P%```!A+I_3_
ML[D$`#BY!``IP.7___A$[";_V@!^6!#PR*4_@`#`&P``\`#L$__08':Y!``I
MISD``<#E___X4.PF_\8`?KD$`#G`(```&"S`Y?___*.Y!``IP.7___?`I_3_
M#<#E___VJP<'!P?KO_!8`"2G.0`OX_#_8/]QN00`LL#E___VO.PH``4`?$&P
M(`&Y!``KZ[_P^``$P/3___>?!P<'!^NO\%``)./P\`#_<>,`__@`(./P_UC_
M<>,`\*``(+)/`+#C$/"@`7'KNP`@``VR3P"QT@<0`+`H["@`:P!\N00`,I4`
M(`"GA`!DIP@``*=)``"R7@!"IQ3__J<)$`"Y"0!#ITL``>Q``'<@94&@\*"Y
M!``JP.7___50IP@``*<Y``"Y!`!:LEX`-:<4__[C$#___W'L&@`?P&6YZ:#A
MIQ$``:=T`$?K3@`!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?
M_O]QIT?_[[D$`"JG.0`OP.7___8]["@`%P!\["H`,R!EN00`*L#E___W(N,P
M\*`!<=4',`"P**=T`"WKK_#X`00'_N,@\*`!<=4'(`"P**=T`"'`(```%VGK
MK_#X`03`]/__]P65+Q``IW3_SY(`$`#C$!___W'L&O^R8&2G]/_%D@`@`*?T
M_\ZG*0``I_3_S\#E___UW`<'!P<'!^NO\%``)./P_U#_<;)/`*#KJ@`@``VR
M3P"A0;#PI-('\*B@*+D$`#O`(```%S_`Y?__^D7L*``N`'SC0/"D`!3$*```
M2$CK%``#``WC$"````CC4!`(``3C4!```"3L6/_C`'SC`!`0``3C`!`(`"1!
M$!`([`;_^`!\N00`.\`@```7%,#E___Z&NPF_]@`?+D$`#O`(```%P[`Y?__
M^@_L*``N`'SC$/"D`!3$6```2!+KX0`#``WCX%````CC`.`(``3C`.```"3L
M"/_C`'SC,.`0``3C,.`(`"1!X.`([#;_^`!\N00`.\`@```6X\#E___YY.PF
M_]@`?+D$`#O`(```%MS`Y?__^=GL*``N`'SC4/"D`!3$Z```1]SK10`#``WC
M0.````CC,$`(``3C,$```"3L./_C`'SC($`0``3C($`(`"1!0$`([";_^`!\
MN00`.\`@```6L<#E___YKNPF_]@`?+D$`#O`(```%JO`Y?__^:/L*``N`'SC
M,/"D`!3$*```1Z;K$P`#``WC$"````CC0!`(``3C0!```"3L2/_C`'SC`!`0
M``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```6@,#E___Y>.PF_]@`?+D$`#O`
M(```%GG`Y?__^6WL*``N`'SC$/"D`!3$2```1W#K40`#``WC4$````CC`%`(
M``3C`%```"3L"/_C`'SCX%`0``3CX%`(`"1!4%`([.;_^`!\N00`.\`@```6
M3L#E___Y0NPF_]@`?+D$`#O`(```%DO`Y?__^3?L*``N`'SC0/"D`!3$6```
M1SKK-``#``WC,%````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``3C(#`(`"1!
M,#`([";_^`!\N00`.\`@```6(,#E___Y#.PF_]@`?+D$`#O`(```%>W`Y?__
M^0'L*``N`'SCX/"D`!3$*```1P3K'@`#``WC$"````CC,!`(``3C,!```"3L
M./_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```5PL#E___XUNPF
M_]@`?+D$`#O`(```%>7`Y?__^,OL*``N`'SC$/"D`!3$.```1L[K00`#``WC
M0#````CC`$`(``3C`$```"3L"/_C`'SC4$`0``3C4$`(`"1!0$`([%;_^`!\
MN00`.\`@```5NL#E___XH.PF_]@`?+D$`#O`(```%;3`Y?__^)7L*``N`'SC
M,/"D`!3$2```1ICKXP`#``WCX$````CC4.`(``3C4.```"3L6/_C`'SC(.`0
M``3C(.`(`"1!X.`([";_^`!\N00`.\`@```5B<#E___X:NPF_]@`?+D$`#O`
M(```%8/`Y?__^%_L*``N`'SC4/"D`!3$Z```1F+K%0`#``WC$.````CC(!`(
M``3C(!```"3L*/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```5
M6,#E___X-.PF_]@`?+D$`#O`(```%1K`Y?__^"GL*``N`'SC$/"D`!3$*```
M1BSK,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``3C0#`(`"1!
M,#`([$;_^`!\N00`.\`@```4[\#E___W_NPF_]@`?+D$`#O`(```%1S`Y?__
M]_.Y!``R["@`"0!\P"```!4'P.7___E0N00`.\`@```5$L#E___WX+D$`#+L
M*``)`'S`(```%1#`Y?__^3VY!``[P"```!4.P.7___?-N00`,NPH`!H`?,`@
M```4KL#E___Y*M4'\*B@**=T`"/`,```%0G`(```%,#KK_$```3`]/__^1FY
M!``[P"```!3RP.7___>IN00`,NPH_^4`?,`@```4N,#E___Y!J?T_]S`Y?__
M\Q,'!P<'Z[_P6``DP"```!2HX_#_4/]QLD\`L$$P\*3KNP`@``VR3P"QT@?P
MJ+`HP.7___=_["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!5=4'
M\*BP*+D4`".G=``*Z[_Q"``$!_ZG.```I_3_\\#E___RU@<'8`#P@&`@\(A@
M0/"08&#PF.L_\!@`),08``!%>>/P_SC_<;D$`#)!`/%HLD\`($%0\,CK0@`@
M``VR3P!!XR`0```$T@?PP$`HXP#PL``DXU#PN``DY4CPH``!Y4CPJ```04#P
MH,#E___U`*<I`/_`Y?__]$L'!P<'ZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@
MN2$`_J<D__BY!`#^X_#_4/]QXP#PJ``@XQ#PJ!!QN00`@K)/`*"G20`"ZZH`
M(``-ISD``+)/`*'2!Q``H"C`Y?__\EOLDO__`-GL"3"``%7LE`"Z`'RY"0"0
M0;#PH.R4`)\`?+D$`#FY!``HITD``,#E___R0NPH`+C_?+D$`#NY!``HP$$`
M`0`(P.7___+E["@`I?]^N10`,NP\`'@'?>,3O_C_<>P;`')`9>Q!/K\`5<!0
M``!$\]4'4``0`*>$`'WC$!___W'L&P!A0&7L2``M`'SL2``<`7SL2``.`GS`
MX```1-S5!^``$`"GA`!FXQ`?__]QP"```$31U0<@`!``IX0`6^,0'___<<`P
M``!$QM4',``0`*>$`%#C$!___W'L&P`T0&7`0```1+C5!T``$`"GA`!"XU`?
M__]QP.```$2MN00`%=4'X`!0`*>$`#7C$%___W'`(```1*#5!R``$`"GA``J
MQ`@``$28XQ!?_O]QXP!?_O\@IX0`'^,07_W_<>P;_]*@9<*4``$``,`Q__\`
M`.R3_V=@9*<I___C@/"H$''5!X``H"BG=``CZX_P\!`$!_ZYZ;`AN0@`*:?T
M__"G"___P"'__P``N8$``J<+``&G]/]`P"```!-ZP.7___[(P"```!-MP.7_
M__["P.7___&1Z^_P<``DX_#_8/]QP.7___$8P.7___*U["@`!@!\XR`@```$
MZ^_Q$``$!_X'!P<'ZV_P,``DX_#_4/]QLD\`H+D$`++KJ@`@``U!,/"DLD\`
MH<`@```32-('\*B@*,#E___UY>PH`$``?+D$`&*5`"``IX0`.;D$`#O`Y?__
M\>'L*``,`'S5!_"HH"BG=``\ZV_PX``$!_ZG"```N00`&[D$`#:G20``LEX`
M0Z<4__ZY"0!&LEX`(:<4__ZY"0`K02)``L#E___PW+D$`$O`4```$J*Y!`"R
MP#```!,8P.7___)OU0?PJ*`HIW0`#;D$`#O`(```$OCK;_#@``3`]/__]OW`
MY?__\0P'!P<'!P?K;_`P`"3C\/X@_W&R3P!PZW<`(``-LD\`<<`0``!#N]('
M\=AP*-(/\+@0$-('\,@0(-(O\.@0*-(/\-`06-('\.`0:$&0\+2Y!`#2N00`
M.<`@```23<#E___U8>PH``D`?+D$`+*5`"``IW0"1L#E___P7\#E___Q_.PH
M`0P`?..`(````J>$`0:G"```IRD``+D$`#BR7@`CIQ3__KD)`"CK(@`!``VG
M*P`!P.7___!@XT"```"4N00`LKD$`&*5`(``IX0`%[D$`"NYA`!$P#```!*-
MP.7___'K08"``4&PL`+C0(```)25`(``IW3_[4&@\/#`(```$DFG]``)IZL`
M".,@K_C_`J>$`""Y!``YP.7___4#N00`@NPH__(`?)4`(`"GA/_MP.7___5G
M["C_Z`!^N00`*,#E___Q>;D$`++L)@`=`'Q!H/"XX["@```"IX0`%94`L`"G
MA`"7N00`*\#E___U2NPF`((`?J>K``CCL*````*G=/_OIP@``+D$`%:Y!``K
MISD``*=)``"R7@`RIQ3__K)>`$6G%/_^N0D`.[D)`$8:-*<Z!`2Y%`"CN00`
M*L#E___OVN-@\*``)+D$`(+`,```$A>Y!`!+P&```!(/P%```!&6P.7___%G
MN00`**<Y`<#`Y?__\D#L)@`+_W[`Y?__\:I8`"``[`8!91%^N00`*$$P\1C`
MY?__\'X8LNPF``T`?EA@\3"GZ$``P&L``/``[&X`>(!VN00`6.-`T```!,2(
M``!"FL`P```1_>,@@```!,#E___P'Z>I``#5!_'8<"BG=`'DN00`*NMO\A``
M!`?^N00`*Z>K``C`Y?__\-NY!`"R["C_9P!\I_3_?*>Y``"G]/]X0:#PT.,@
MH````J>$`!6Y!``YP.7___0Z["@`!P!\E0`@`*=T`!FGJP`(XR"@```"IW3_
M[Z<I``W`@```$8S`Y?__[TZG2`!3N00`LKD$`&*G]/[SP.7___"CN00`@NPH
M_^0`?+D$`!*G"```I^D``+)>`.&G%/_^N0D`XNLN``$`#:<K``&G]/[*6&#Q
M-,#E___O!NQB_X9@=E@0\3"G.`'`P!L```'_[!/_?&!VN00`*L#E___O%+D$
M`#FY!`"BP"```!&?P.7___/@N00`,NPH`-H`?.,@T```!,#E___W<;D$`&+L
M*`#/`'RG"```ITD``+D$`":R7@!"IQ3__KD)`$;L3``>`WZY%`!4P.```!%[
MXQ5O_/]QLET`X:<4__ZG=``/[$@!%01^ITK_^[D4`#1!0V``E2]``*>$`0JY
M!``YP"```!"XP.7___.>["@`GP!\XY`@``"4[)@`F0!^[)@`EC!^P#```!#>
MP"```!"CP.7___3QP.7__^Y`P````!&JN00`8KD$`$BY!``JXP#PH``DP%``
M`!!MP#```!%'P.7___`[I_0`*L#E___PAEA`(`"G3@`1IW0`*\#E___N'<!0
M```1AZ>Z``&Y%``;N00`8N-0\*@`)+D$`$BY!``JP%```!!&XQ#PH``DP#``
M`!$DP.7___`1N00`*J<Y`<#`Y?__\.KL*/_1_WZY!``HP.7___$BN00`.L`@
M```0',#E___TF+D$`"K`Y?___2^G]/[(N00`6+D4`&#C0-````3$*```04O`
M,```$)#C("````3`Y?__[M"G]/ZQP.7___T5U0?QV'`HIW0`DKD$`"OK;_(0
M``3`]/__[X[C8-````2G]/\QN00`)J<Y``#`Y?__\%*Y!`#2["C_9`!^P.7_
M__O4N00`8NPD_UP`?*=)``#C,&_V_W&Y!``MP.7__^Y+N00`+4$P\:FG20`&
MP.7__^[R["8`7P9\P#```"_/U04P`/&IIW3_/>,P;\[_<:=)``"Y!``MP.7_
M_^XM06#QK[D$`"VY!``VITD`*,#E___NTNPF`#\H?,#@```0V;D$`$BY!``J
MD@#QU^/@\*``),!0```/G,`P```0;L#E___O:J?T_V/CT-`(``*GA/[UIP@`
M`*<I``"Y!`!=LEX`):<4__ZY"0`M["S^YP-]X^+?_/]QP!```!!&LET`'J<4
M__ZYXH!MI_3^V,#E___M\\`@```0.\#E___[&^MO\#``)./P_U#_<<"@``!`
MFK)/`+#C$*````3KNP`@``VR3P"QXY&P```$08#PI-('\*BP*-(`D+&0L+D$
M`#C`(```#UG`Y?__\DWL*``'`'R5,2``IX0`S<#E___WY^,@H```!..2L```
M!+D$`"FG60`#ITD``<`P```0%\#E___O"[D$`&+L*``?`'SC,"`0``3C<*``
M``3C,#````3`0```$`3C)[````3`Y?__[<3C0&`0``3C,$````210#`-IW0`
MNN-PH```!*=9``/C)[````2G20`!P#````_JP.7__^[:N00`DNPH`!P`?+D$
M`#C`(```#N3`Y?__\?.Y!`!"["@`?`!\XS"0$``$XR>P```$XS`P```$P.7_
M_^V,XZ"@```$ITD``>-ZL```!,`P```/O[D$`"?`Y?__[DS`0```#\*Y!``R
MN00`)\#E___M<KD$`#C`(```#JSCBK````22`("QP.7___&[Q"L``$!4["@`
M*P!\ISD!P,#E___O6NP"``$`V.P,`!<!?^PH`!01?KD$`%+$N```0#K$2```
M0#OC,+````3`(```#Z#`Y?__["#5!_"HL"BG=`!7ZV_PX``$!_[$*```0"+`
MY?__^_O$*P``0"#L)O_/`'S`(```#W3`Y?__[`65`"`!IX3_/*?T_S'`Y?__
M]':Y!`!B["@`(`!\XQ"0$``$N00`0N,P$```!.,GL```!,#E___M";D$`";`
MY?__[T2G]/]XXR>P```$P.7__^PLI_3_0N-0D!``!,3H```_XN,GL```!.,P
M4```!.-`X```!,#E___LZ*?T_US`Y?__[+,'!P<'ZY_P2``DX_#_4/]QLD\`
MH+D$`)+KJ@`@``VR3P"AT@?PJ*`HP.7___82ISD`+[D$`++`Y?__[+7L*``%
M`'Q!L"`!N00`*\#E___MFT$P\*2Y!`"RP"````XAP.7___$'["@`$P!\XQ`@
M``"4[!@`#0!^[!@`"C!^[)@`!P!\E0"0`*=T``O5!_"HH"BG=``@ZY_P^``$
M!_ZY!``KITD`!,`P```.4,#E___M"^PF_^T`?M4'\*B@**=T``JY!``IZY_P
M^``$P/3___&)P.7__^Q(!P<'!P<'ZV_P,``DX_#\T/]QLD\`L.N[`"``#;)/
M`+%!$/"HT@?S*+`HIPD`!$%0(#CC0%````3C,%`(``3KI``@``SCH!```"3K
M8P`@``SC8!`0`"3`2@````#C0!`(`"3`.@````#C,!`8`"1!4%`0IQL`(*<'
M_][C,/$0``3C@/$8``3C$/$@``3CD/"H``3C`/"P``1!0/"XIZD`0+D$`''C
MT$````2Y!`#MX^!`,`""N8(`X[F"`.GL'B"_(57L'B`^`5;C$$!P`"2Y!``X
MN00`D+D$`(>G2P`(IZ<*V./@(```!.-@(`@`!.-@\*``).-`(!``!.,`(!@`
M!.RN(+\E5;GG`)3LKB`Z!5:Y@`"6N8(`D.M6``(`#.-P\+``!.Q6`"$>5L)Z
M6H)YF>PU(+\`5;D(`'"YYS#4XQ#PJ``$N8``WL(:6H)YF;F"`-3C$"`@``BY
MZ'"-N0@`&NNN``(`#+D(`!GLK@`A'E;LD2"_`%6YYZ!EN8``:;F"`&/LT3N_
M)57C4/#```3LV0`Z!5;"6EJ">9FY"`#8N0@`4^Q](+\`5>R-.[\E5>LY``(`
M#.R'`#H%5NPY`"$>5N,0\+@`!,(:6H)YF;D(`!2Y"``6[&H@OP!5N8(`H[D(
M`!BYY'"*[)$@OP!5[-$[OR55N00`K>RI`#H%5KF"`(;C$/#(``2Y"`"%PAI:
M@GF9N0@`BKGH8%'KIP`"``SL8R"_`%7LIP`A'E;L>""_`%7LB#N_)57LAP`Z
M!5:Y@@`ZX]#PT``$N8``.<+:6H)YF;F"`#:Y"``UN>A@7;D(`#CL:B"_`%7K
MB0`"``SLB0`A'E;LDR"_`%6Y@@"H[#,[OR55N>1P&N/0\-@`!+F"`!;"VEJ"
M>9FY"``5N00`H[GH8%WLJ0`Z!5;L:""_`%6Y"``:ZS<``@`,[#<`(1Y6N8(`
M@^QQ(+\`5>RA.[\E5;GDD!BY!`"*[(<`.@56N8(`%N/0\.``!+D(`!7"VEJ"
M>9FY"``8N>A@7>RA.[\E5>QC(+\`5>N)``(`#.R)`"$>5NR1(+\`5>RI`#H%
M5KF"`#CC$/#H``2Y@``WPAI:@GF9N8(`-KD(`#6YZ&!1N0@`.NQH(+\`5>NG
M``(`#.RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C
M$/#P``2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H
M[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#P^``$N0@`-<(:6H)Y
MF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E5;GD
MD#BY!`"-[(<`.@56N8(`-N,0\0``!+D(`#7"&EJ">9FY"``XN>A@4>N)``(`
M#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%5KF"
M`#;C$/$(``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A'E:Y
M@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q$``$N0@`-<(:
M6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E
M5;GD<#JY!`"M[*D`.@56N8(`-N,0\1@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG
M``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%
M5KF"`#;C$/$@``2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A
M'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q*``$N0@`
M-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3
M.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\3``!+D(`#7"&EJ">9FY"``XN>A@
M4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)57C$/$X``2YY'`Z
MPAI:@GF9N8(`-KD$`*VY"``U[*D`.@56N>A@4;D(`#KL:""_`%7LTSN_)57K
MIP`"``SLTR`Z!5;LIP`A'E;`.@````"YYZ!XXX#Q0``$N8``><**6H)YF;F"
M`':YZ&`8N0@`=>M9``(`#+D(`'WL60`A'E;LESN_)57LER`Z!5;L:B"_`%6Y
MYU#:ZX,``@`,N8``T[F"`-:Y"`#1N0@`V;D$`)CLDP`A'E;L/3N_)56YYY`5
M[#T@.@56N8(`%^.@\4@`!..`\5``!,*J;MGKH<**;MGKH;D(`*:Y&@"%N1H`
MH>QG(K\^5;D(`*/L9P(A'E;L.CN_)56YYV`9[#H@.@56N8(`'>Q](K\^5;D:
M`('L?0(A'E:Y"`"#XS#Q6``$PCINV>NAN>=P5KD:`#FYYZ"5[!@[OR55N1H`
M.>P8(#H%5N.0\6``!+D(`#'"FF[9ZZ'LTSN_)56Y&@"6[-,@.@56[&HBOSY5
M[&H"(1Y6XZ#Q:``$N>=@5\*J;MGKH;F"`%BY&@"GN1H`E>QX(K\^5;D(`)WL
M>`(A'E;LB3N_)57LB2`Z!5:YYW#6L\$`:..`\7``!,**;MGKH;D:`(:SS0!F
MN8(`T[D:`*VY"`"F[%H[OR55[%H@.@56[&,BOSY5XQ#Q>``$[&,"(1Y6PAIN
MV>NAN>=@-[D:`!>Y@@`Y['DBOSY5N1H`@^QY`B$>5KD(`(6YYW!6[)@[OR55
MN8(`6NR8(#H%5KD:`!7C,/&```2Y"``9PCINV>NA[)HBOSY5N1H`-NR:`B$>
M5NS1.[\E5;GGD%?LT2`Z!5:Y@@!8XZ#QB``$N1H`-<*J;MGKH;D(`#VY&@"G
M['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=PV;/!`'CC@/&0``3"BF[9ZZ&Y
M&@")L\T`E[F"`-&Y&@"MN0@`J>Q:.[\E5>Q:(#H%5NQA(K\^5>QA`B$>5N,0
M\9@`!+GG8-?"&F[9ZZ&Y@@#3N1H`%[D:`(WL<R*_/E6Y"`"%[',"(1Y6[#@[
MOR55N>=P5NPX(#H%5KF"`%KCD/&@``2Y&@`5PIINV>NAN0@`$[D:`);L.B*_
M/E7LT3N_)57L.@(A'E;LT2`Z!5:YYS!7XZ#QJ``$N8(`6,*J;MGKH;D:`)6Y
M&@"GN0@`G>QX(K\^5>QX`B$>5NR).[\E5>R)(#H%5KGG<-.SP0!HXX#QL``$
MPHINV>NAN1H`@[/-`#:Y@@#1N1H`K;D(`*/L6CN_)57L6B`Z!5;L82*_/E7L
M80(A'E;C$/&X``2YYV#7PAINV>NAN8(`V;D:`!>Y&@"-['DBOSY5N0@`A>QY
M`B$>5NR8.[\E5;GG<%;LF"`Z!5:Y@@!:XS#QP``$N1H`%<(Z;MGKH;D(`!FY
M&@`V[)HBOSY5[-$[OR55[)H"(1Y6[-$@.@56N>>05^.@\<@`!+F"`%C"JF[9
MZZ&Y&@`UN1H`I[D(`#WL>"*_/E7L>`(A'E;L@SN_)57L@R`Z!5:YYW#9L\$`
M>..`\=``!,**;MGKH;D:`(FSS0"7N8(`T>QA(K\^5;D:`*WL80(A'E:YYV#7
MN8(`T[D(`*FY&@"-[%H[OR55[-,BOSY5[%H@.@56[-,"(1Y6N>?0EKF"`)JY
M"`"%XQ#QV``$[#@@OP!5[%@[OR55PAINV>NA[%,`.@56N1H`%[D:`!GLFB*_
M/E6Y"``5[)H"(1Y6XZ#QX``$N>>0?<*J;MGKH;F"`(>Y&@"F[&$@OP!5[!$[
MOR55[!8`.@56N1H`J..`\>@`!+D(`*'"BH\;O-SK$P`"``RY&@"-[!,`(1Y6
M[-$@OP!5N>306;/!`"CL.CN_)57LBB"_`%6YYA"IN8``IKF!`*6SS0!2XW#Q
M\``$PGJ/&[S<[#@`.@56N0@`I;D$`%?C</'X``2Y&@!9PGJ/&[S<ZY8``@`,
M[)8`(1Y6N>30:;F!`!FYZ-#7N8``&+F!`!:Y"``5N0@`H[/!`&WL.B"_`%7L
MJCN_)57LHP`Z!5:Y"`"AZQ@``@`,[!@`(1Y6[-$@OP!5N>306>QJ(+\`5>R*
M.[\E5;GF$*FY@`"CN8$`I;/-`%;LA@`Z!5;C</(```2Y"`"EN0@`J,)ZCQN\
MW.N#``(`#+D$`%?L@P`A'E:Y&@!9[#H[OR55[)H@OP!5N8$`&+GDT*BY@``6
MN8$`&KD(`!7L.0`Z!5;C</((``2Y"``QPGJ/&[S<ZQ8``@`,N>C0U^P6`"$>
M5NQA(+\`5;GD8%BSP0`]N>80V+F``-FY@0#5L\T`4^QS(+\`5>PS.[\E5>PW
M`#H%5KD(`-6Y"`#3ZSD``@`,[#D`(1Y6N>1@D[F!`!/CH/(0``2Y@``7PJJ/
M&[S<N8$`&;D$`%JY&@!8[(T@OP!5N0@`%>S=.[\E5>S8`#H%5KD(`-'LG2"_
M`%7K%P`"``SL%P`A'E;C</(8``3">H\;O-RYZ&!G['$@OP!5N>1P4[GF$*.S
MP0!VN8``J+F!`*6SS0!7[-T[OR55XV#R(``$N0@`I>S9`#H%5L)JCQN\W+D(
M`-JY!`!6[*T@OP!5N1H`4^S=.[\E5>LX``(`#.S:`#H%5NPX`"$>5KGF,(&Y
MY'`3N8``B;F!`('K&0`"``RY"`"%[!D`(1Y6N0@`C>S1(+\`5;GDT%.YYA"3
MXV#R*``$N8``FL)JCQN\W+F!`)6Y"`!GL\$`)K/-`%+L>""_`%7C8/(P``2Y
M"`"5PFJ/&[S<[(@[OR55N00`5NR'`#H%5KD:`%.YZ(`YZYH``@`,[)H`(1Y6
MN>30J;F!`!FY@``7N8$`&KD(`!7L@R"_`%7L8SN_)57C,/(X``3L:``Z!5;"
M.H\;O-RY"`!AZQ<``@`,[!<`(1Y6['$@OP!5N>1P6;GHT-.YYA`YL\$`;;F`
M`#BY@0`UL\T`5N/0\D``!,+:CQN\W.RF(+\`5;D(`#7L9CN_)56Y!`!=[&H`
M.@56N1H`6>/0\D@`!.N8``(`#,+:CQN\W.R8`"$>5KGD<(FY@0`9N>AP?;F`
M`!JY@0`8N0@`%;D(`#:SP0`W[&,@OP!5[#,[OR55[#8`.@56N>@P4>L:``(`
M#.P:`"$>5NS1(+\`5;GDT'FYYA"IN8``IKF!`*>SS0!S[#4@OP!5[(4[OR55
MN0@`I^R#`#H%5KD(`*CC4/)0``3L>B"_`%7LBCN_)57"6H\;O-SCH/)8``2Y
M&@!9PJJ/&[S<ZY8``@`,[)8`(1Y6N>30:;F!`!FYZ-#:N8``$[F!`!:Y"``5
M[(<`.@56L\$`?;D(`('K$P`"``SL$P`A'E;LT2"_`%6YY-!9N>80J;F``*>Y
M@0"EL\T`5^QH(+\`5>PX.[\E5;D(`*7L-@`Z!5;C@/)@``3"BH\;O-RY!`!8
MN1H`6>N7``(`#.R7`"$>5KGDT'FY@0`9N8``%KF!`!>Y"``5N0@`H^.`\F@`
M!.PZ(+\`5<**CQN\W.RJ.[\E5>RC`#H%5KD(`*'K%@`"``SL%@`A'E;L82"_
M`%6YY&!9['H@OP!5N>C0V.R*.[\E5;/!`"VYYA"IN8``H[F!`*6SS0!2[(<`
M.@56X]#R<``$N0@`I<+:CQN\W+D(`*BY!`!=N1H`6>S:(+\`5>N3``(`#.R3
M`"$>5NPZ.[\E5;GD8(FY@0`9[#T`.@56N8``%^.@\G@`!+F!`!C"JH\;O-RY
M"``5N>A@6KD(`#'L8SN_)57L8R`Z!5;K%P`"``RSP0!F[!<`(1Y6XV#R@``$
M[($@OP!5N>80>;GD@*G":H\;O-RY&@!IL\T`EKF``'VY@0!ZN0@`=;GHD)?L
M63N_)57L62`Z!5:SP0`6ZWT``@`,['T`(1Y6N00`U;/-`%&YY("GXV#RB``$
MPFK*8L'6N>B`AL`Z`````+F!`!>SP0`XN8``$^N#``(`#+F!`!KL@P`A'E:Y
M"``5L\T`8[D(`!WCH/*0``2YYX#7PJK*8L'6N8(`V;D:`*?L>2*_/E7L>0(A
M'E;CD/*8``3"FLIBP=:Y&@"8L\$`6K/!``FSS0"5N1H`;>PQ.[\E5>PQ(#H%
M5KD(`#;L4SN_)57L4R`Z!5:YYW"HN8(`H;D:`)JY"`"5L\T`4.QA(K\^5>QA
M`B$>5KGG8->Y@@#3[!D[OR55N1H`7>P9(#H%5KD(`!7LH3N_)57LH2`Z!5:S
MP0`JL\T`TN.`\J``!..@\J@`!,**RF+!UL*JRF+!UKD:`(>Y&@"F[',BOSY5
M[',"(1Y6N>=P-NQI(K\^5;F"`#GL:0(A'E:Y&@"#N>=@5[D(`(VY@@!1[)@[
MOR55N1H`I>R8(#H%5KD(`*GLVCN_)57LVB`Z!5;LD2*_/E7C,/*P``3LD0(A
M'E;".LIBP=:YYY!6N1H`-[F"`%BY&@`UN0@`/>S3.[\E5>S3(#H%5N,0\K@`
M!+/!`!W"&LIBP=;CT/+```2Y&@`6PMK*8L'6[&@BOSY5N1H`V>QH`B$>5KGG
M8(FSS0"1N8(`BNQZ(K\^5;D:`!CL>@(A'E:Y"``9N>=PANQ1.[\E5;F"`(/L
M42`Z!5;CH/+(``3"JLIBP=:Y&@"FN00`;>S3(K\^5;D:`&BY"`!E[-,"(1Y6
MN>?0-[F"`#'L5CN_)56Y&@"C[%8@.@56N0@`I>PZ.[\E5>PZ(#H%5N.`\M``
M!,**RF+!UKD:`(?L<2*_/E7L<0(A'E;C$/+8``2YYW!=PAK*8L'6N8(`5KD:
M`!VY&@"%[-8BOSY5N0@`@^S6`B$>5NPX.[\E5;GGT&?L."`Z!5:Y@@!JN1H`
M%KD(`!/L.B*_/E7L.@(A'E:YYS!MN8(`:.Q1.[\E5>.0\N``!.Q1(#H%5L*:
MRF+!UKD:`)>Y&@"6[&@BOSY5N0@`E>QH`B$>5NR).[\E5>R)(#H%5KGG8'.S
MP0!(XX#R\``$PHK*8L'6N1H`@[/-`#2Y@@!QXZ#RZ``$PJK*8L'6N1H`K;D:
M`*?L<2*_/E6Y"`"C['$"(1Y6[%H[OR55N>=PUNQ:(#H%5KF"`-GC$/+X``2Y
M&@"-PAK*8L'6N0@`A;D:`!;L:2*_/E7L:0(A'E;LF#N_)56YYV!7[)@@.@56
MN8(`6KD:`!6Y"``9[-$[OR55[-$@.@56[)HBOSY5XS#S```$[)H"(1Y6PCK*
M8L'6N>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;CH/,(``2SP0!=
MPJK*8L'6X]#S$``$N1H`IL+:RF+!UNQH(K\^5;D:`-GL:`(A'E:YYV")L\T`
ME;F"`(&Y&@"H[($BOSY5[($"(1Y6N>>`=KF"`'.Y"`"IN1H`U^Q:.[\E5>QS
M(K\^5>Q:(#H%5NQS`B$>5KD$`#?C,"`@``C`.@````#C,"`@`"3C$/,8``3"
M&LIBP=:Y&@`6N>A0;;GG<-CLEB"_`%6YYZ`][%8[OR55N1H`$^Q9`#H%5KD(
M`!7LVB*_/E7K60`"``SLV@(A'E;L60`A'E:YY]`WN0@`5+GH`'W`6@````#C
M4"`0`"2YYV`#P'H`````XW`@&``D[&$@OP!5XZ#S(``$PJK*8L'6N0@`ZKD:
M`.CL@3N_)56Y&@#@[(8`.@56XQ#PH``$N0@`Z+D(`!;`Z@````#CX"```"3`
M&@````#C$"`(`"35!_,HL"BG=``*ZV_S8``$!_ZY!``-I_3U!\#E___@^@<'
MZ^_P<``DIRD`@./P_V#_<<#E___@GL`Q9T4C`<`/[\VKB>,P(```).,`(`@`
M),!/F+K<_L!1$#)4=N-`(!``).-0(!@`),`_P]+A\.5(("@``.,P("``).5(
M(#```.5,('@``.OO\1``!`?^!P<'!^MO\#``).L4``,`#;D$`'+C("`H``2Y
M"``2[%$@OP!5N00`M./P_UC_<>-`<#``!+D$`-.Y,0`AI\0`!*=+``'C4'`H
M`"3K"P`=``RY"``$XP!P,``DXS!P>``2IW0`9$%@<#CLO``X/W[LZ__``-CL
MG0!``-GKC@`&`-ZGB@`!$NZG&``!N?)0@4$@<'BY!`"MXR#PH``DN2$`:J>D
M`#7C4/"@``3L6@`W(&6Y!`#9TC]@`*``N00`)Z>Z_\"GJP!`P.7___0;N10`
MNZ>;`$"GAO_DN2$`;:=$`""GQ``&N>BP3;EA0&2Y!``]N00`)KD$`$O`Y?__
MWY10L'!XZV_PV``$!_ZY!`#9I\3_T^QI_]&@9:?T``&YZ+`&N6%`T*?T_^2G
MJ`!`&Z,9JT%@<#BY\C"KN00`)KD8`".Y%`!*["T`(J!EN>A`@KGH0)VY84#8
MN00`/1C:P.7__]]B6M!P>%#0<'CLUO_,0'ZY!``G&[JY!`#9P.7___/!N10`
MNZ?T_W*YZ$"=["W_Y<!EN6%`*:?T_^`'!^M_\#@`)+D$`+/C@#`H``3CD#`P
M``3L&#J_/56Y%``Q04.P.)*`0`"G&@`!N00`HKD4``%!(+`XX_#_8/]QN0@`
M(.P<`)XX?J?H`$"Y^1`^[.$`7X!V[!/__P#8N00`,NM!``@`WNQ(`$\`?NQT
M__\`V!A4[`0^OP!5IX0`)NP(`!D!?NP(``P"?N,@)```-AA'03`A`-?_(``@
M`.,@-```-J=*___7_S``,`!!,#$`XR`T```VU_\P`#``03`Q`.Q(`"(!?NLE
M``(`WN,@-```-M?_,``P`.,@-0``-M?_,0`Q`.,@-@``-M?_,@`R`.,@-P``
M-M?_,P`S`$$P-`"G)O_FN18`X<;@````H+D$`"O`Y?__\R?7-[`XL#BG.0``
M[#D`!V!5[#D(#V!5[#D0%V!5[#D8'R!5N00`*^R#`!\`5>.`L'``),#E___S
M"](#H`"P!+D$`"O2`Z`$L`S2`Z`(L!32`Z`,L!S2`Z`0L"3K?_#8``3`]/__
MX::G6``XN?D0=>Q1_\R`=NP7__\`V+D$`#+K<0`(`-[L>`!/`'[LY___`-@8
M5^P'/K\`5:>$`";L"``9`7[L"``,`G[C("0``#88?D$P(0#7_R``(`#C(#0`
M`#:G>O__U_\P`#``03`Q`.,@-```-M?_,``P`$$P,0#L>``B`7[K10`"`-[C
M(#0``#;7_S``,`#C(#4``#;7_S$`,0#C(#8``#;7_S(`,@#C(#<``#;7_S,`
M,P!!,#0`IT;_YKD6`"'&(`````BG]/]MUP`P`#``UP`P`#``!P<'!^OO\'``
M)+D$``^G^_]@XP#P```DZ^_Q$``$!_X`````)7,O)7,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4``!E>&4`+W!R
M;V,O)6DO)7,`+@!005)?5$5-4```4$%27U!23T=.04U%```Z`"\`4$523#5,
M24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!
M4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```Q`&QS965K(&9A
M:6QE9```<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R
M>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@``'!A<FP``"YP87(`
M`'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S
M)7-T96UP+25U+25U)7,``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D524TE/
M3@``,2XP-3D`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``"UE```M+0``55-%4@``55-%4DY!344``%1%
M35!$25(`5$U0`"]T;7```&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%
M7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[
M("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?
M34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*
M;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I
M("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S
M(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@
M,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@
M)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O
M9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD
M(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I
M('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,[
M"GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@
M7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N
M<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&
M24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S
M96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&
M24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R
M('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````
M<&5R;'AS:2YC``!#04-(10```````````1L#.P```-0````9__^!\```!6C_
M_X7X````\/__AM@```%0__^':````8#__XC(```!N/__BU````'X__^+R```
M`C3__XP````"2/__C2@```*,__^-,````J#__X^@```"X/__C]@```,,__^1
M0````U#__Y;0```#A/__ET@```.T__^7P````^#__YG0```$)/__F@````1$
M__^:X```!)3__Z$8```$Y/__HY````4D__^D:```!:C__[L````%Z/__NW``
M``8,__^]"```!D@`````````%``````!>E(``7@.`1L,#Z`!````````7```
M`!S__X4`````W`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`I@*S\[-S,O*
MR<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@M."L_.S<S+RLG(Q\8.H`%""P``
M````+````'S__X6`````D`!&B@J+"8P(C0>.!H\%1@[8`P)\"L_.S<S+R@Z@
M`4(+````-````*S__X7@```!8`!&B`R)"XH*BPF,"(T'C@:/!48.V`-V"L_.
MS<S+RLG(#J`!0@L````````\````Y/__AP@```*(`$:&#H<-B`R)"XH*BPF,
M"(T'C@:/!48.V`(#`58*S\[-S,O*R<C'Q@Z@`4(+````````.````23__XE0
M````=`!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L@"`F#/SLW,R\K)R,?&#J`!
M````````$````6#__XF,````.`````````!````!=/__B;````$D`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.H"%,#J!!3`[00@+D"L_.S<S+RLG(Q\8.H`%"
M"P```!````&X__^*E`````8`````````/````<S__XJ(```";`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5&#J`A3`[H(P)Z"L_.S<S+RLG(Q\8.H`%""P```"@`
M``(,__^,N````#0`2HL)C`B-!XX&CP5&#L`"7L_.S<S+#J`!````````0```
M`CC__XS$```!8@!&B@J+"8P(C0>.!H\%1@Z@(4P.R"("]`K/SLW,R\H.H`%"
M"UP*S\[-S,O*#J`!1@L````````P```"?/__C>@```6,`$:*"HL)C`B-!XX&
MCP5&#M`"`P5*"L_.S<S+R@Z@`48+````````+````K#__Y-$````=@!,BPF,
M"(T'C@:/!48.T`("5`K/SLW,RPZ@`4(+````````*````N#__Y.,````=`!<
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"``````!````##/__D]@```(0`$:(
M#(D+B@J+"8P(C0>.!H\%1@P.H($$6`T/1@[0@@0#`:0*S\[-S,O*R<@.H`%"
M"P```````!P```-0__^5I````"P`1HX&CP5&#L`"7L_.#J`!````3````W#_
M_Y6T````V@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`EH*S\[-S,O*R<C'
MQ@Z@`4(+`F8*S\[-S,O*R<C'Q@Z@`48+``````!,```#P/__ED0```8X`$:&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.@`4#`F`*S\[-S,O*R<C'Q@Z@`4(+`P*B
M"L_.S<S+RLG(Q\8.H`%&"P```#P```00__^<+````G0`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[0`@,!O@K/SLW,R\K)R,?&#J`!0@L```````!````$4/__
MGF0```#2`$:)"XH*BPF,"(T'C@:/!48.T`("B@K/SLW,R\K)#J`!0@MN"L_.
MS<S+RLD.H`%&"P```````#P```24__]\@````H``1H8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[H`@,!P`K/SLW,R\K)R,?&#J`!0@L````````\```$U/__GK@`
M`!:6`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#%GH*S\[-S,O*R<C'Q@Z@
M`4(+````````(```!13__[40````;`!*C@:/!48.P`("6L_.#J`!````````
M.```!3C__[5<```!E@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5>#L@"`MH*S\[-
MS,O*R<C'Q@Z@`4(+````.```!73__[:X```"5`!&APV(#(D+B@J+"8P(C0>.
M!H\%>`[``@,!.@K/SLW,R\K)R,<.H`%&"P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(U`````````BZ``````````!`````````L@``````````0``
M``````+3`````````!T````````$!0`````````,````````&$@`````````
M#0```````%SX`````````!D```````"[P``````````;``````````@`````
M````&@```````+O(`````````!P`````````"`````!O__[U`````````G@`
M````````!0````````Q```````````8````````#6``````````*````````
M!",`````````"P`````````8`````````!4````````````````````#````
M````O;```````````@````````5``````````!0`````````!P`````````7
M````````$P@`````````!P```````!!H``````````@````````"H```````
M```)`````````!@`````````'@`````````(`````&____L`````"````0``
M``!O___Y`````````!``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+O0`````````````````````````````!B2````````&+(`
M```````8T@```````!CR````````&1(````````9,@```````!E2````````
M&7(````````9D@```````!FR````````&=(````````9\@```````!H2````
M````&C(````````:4@```````!IR````````&I(````````:L@```````!K2
M````````&O(````````;$@```````!LR````````&U(````````;<@``````
M`!N2````````&[(````````;T@```````!OR````````'!(````````<,@``
M`````!Q2````````''(````````<D@```````!RR````````'-(````````<
M\@```````!T2````````'3(````````=4@```````!UR````````'9(`````
M```=L@```````!W2````````'?(````````>$@```````!XR````````'E(`
M```````><@```````!Z2````````'K(````````>T@```````![R````````
M'Q(````````?,@```````!]2````````'W(`````````````````````````
M```````````````82```````````````````````````````````````````
M```````````````````?B```````````````````7/@`````````````````
M``````````````````````#```I005(N<&T*``````````````````!@!```
M`````%U@``````````````````!>`````````%X$````````7_@```````!=
M9@```````&````````````````````!?Z````````%_N````````````````
M``!@"D=#0SH@*$%L<&EN92`Q,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R
M,#(S,3`Q-```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````L````!``````````(````````".`````````(X`````````!@`````
M```````````````!```````````````3````!P`````````"`````````E``
M```````"4``````````D````````````````````!```````````````)F__
M__8``````````@````````)X`````````G@`````````W`````0`````````
M``````@``````````````#`````+``````````(````````#6`````````-8
M````````".@````%`````@`````````(`````````!@````X`````P``````
M```"````````#$`````````,0`````````0C`````````````````````0``
M````````````0`````0``````````@```````!!H````````$&@````````"
MH`````0```````````````@`````````&````$H````$`````````$(`````
M```3"````````!,(````````!4`````$````$@`````````(`````````!@`
M``!4`````0`````````&````````&$@````````82``````````<````````
M`````````````@``````````````3P````$`````````!@```````!AD````
M````&&0````````'(`````````````````````0`````````(````%H````!
M``````````8````````?B````````!^(````````/7``````````````````
M```(``````````````!@`````0`````````&````````7/@```````!<^```
M```````<`````````````````````@``````````````9@````$`````````
M`@```````%T8````````71@```````!`@`````````````````````@`````
M`````````&X````!``````````(```````"=F````````)V8`````````-0`
M```````````````````$``````````````!\`````0`````````"````````
MGG````````"><`````````6P````````````````````"```````````````
MA@````X``````````P```````+O`````````J\``````````"```````````
M``````````@`````````"````)(````/``````````,```````"[R```````
M`*O(``````````@````````````````````(``````````@```">````!@``
M```````#````````N]````````"KT`````````'@````!0``````````````
M"``````````0````IP````$``````````P```````+VP````````K;``````
M```"4`````````````````````@`````````"````*P````!``````````,`
M``````#``````````+```````````(`````````````````````(````````
M``````"R````"``````````#````````P(````````"P@`````````!8````
M````````````````"```````````````MP````$`````````,```````````
M````````L(``````````,0````````````````````$``````````0````$`
M```#`````````````````````````````+"Q`````````,``````````````
.```````!````````````
